pub struct TestbedGraphics<'a> {
pub graphics: &'a mut GraphicsManager,
pub window: &'a mut Window,
pub camera: &'a mut Camera,
pub mouse: &'a SceneMouse,
pub keys: &'a KeysState,
pub settings: Option<&'a mut ExampleSettings>,
}Expand description
Context for graphics operations during a frame
Fields
graphics: &'a mut GraphicsManagerwindow: &'a mut Windowcamera: &'a mut Cameramouse: &'a SceneMousekeys: &'a KeysStatesettings: Option<&'a mut ExampleSettings>Implementations
Sourceimpl<'a> TestbedGraphics<'a>
impl<'a> TestbedGraphics<'a>
pub fn set_body_color( &mut self, body: RigidBodyHandle, color: Color, tmp_color: bool, )
pub fn add_body( &mut self, handle: RigidBodyHandle, bodies: &RigidBodySet, colliders: &ColliderSet, )
pub fn remove_body(&mut self, handle: RigidBodyHandle)
pub fn add_collider(&mut self, handle: ColliderHandle, colliders: &ColliderSet)
pub fn remove_collider(&mut self, handle: ColliderHandle)
pub fn keys(&self) -> &KeysState
pub fn mouse(&self) -> &SceneMouse
Sourcepub fn update_collider(
&mut self,
handle: ColliderHandle,
colliders: &ColliderSet,
)
pub fn update_collider( &mut self, handle: ColliderHandle, colliders: &ColliderSet, )
Update collider graphics after shape modification
Sourcepub fn camera_rotation(&self) -> UnitQuaternion<f32>
pub fn camera_rotation(&self) -> UnitQuaternion<f32>
Get the camera rotation as a unit quaternion (3D only)
Sourcepub fn camera_fwd_dir(&self) -> Vector3<f32>
pub fn camera_fwd_dir(&self) -> Vector3<f32>
Get the camera forward direction (3D only)
Sourcepub fn egui_context(&self) -> &Context
pub fn egui_context(&self) -> &Context
Get mutable access to the egui context for custom UI
Sourcepub fn egui_context_mut(&mut self) -> &mut Context
pub fn egui_context_mut(&mut self) -> &mut Context
Get mutable access to the egui context for custom UI